aboutsummaryrefslogtreecommitdiffstats
path: root/AST.h
diff options
context:
space:
mode:
Diffstat (limited to 'AST.h')
-rw-r--r--AST.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/AST.h b/AST.h
index d028e8a7..967c6792 100644
--- a/AST.h
+++ b/AST.h
@@ -510,7 +510,7 @@ private:
};
/**
* Invocation/usage of a modifier in a function header.
*/
class ModifierInvocation: public ASTNode
{
@@ -525,11 +525,12 @@ public:
ASTPointer<Identifier> const& getName() const { return m_modifierName; }
std::vector<ASTPointer<Expression>> const& getArguments() const { return m_arguments; }
- void checkTypeRequirements();
+ void checkTypeRequirements(std::vector<ASTPointer<InheritanceSpecifier>> const& _bases);
private:
ASTPointer<Identifier> m_modifierName;
std::vector<ASTPointer<Expression>> m_arguments;
+ FunctionDefinition const* m_referencedConstructor = nullptr;
};
/**
@@ -510,7 +510,7 @@ private:
};
/**
- * Invocation/usage of a modifier in a function header.
+ * Invocation/usage of a modifier in a function header or a base constructor call.
*/
class ModifierInvocation: public ASTNode